dask-awkward
============

> Connecting [awkward-array](https://awkward-array.org) and
[Dask](https://dask.org/).

[![Tests](https://github.com/ContinuumIO/dask-awkward/actions/workflows/pypi-tests.yml/badge.svg)](https://github.com/ContinuumIO/dask-awkward/actions/workflows/pypi-tests.yml)
[![Tests](https://github.com/ContinuumIO/dask-awkward/actions/workflows/conda-tests.yml/badge.svg)](https://github.com/ContinuumIO/dask-awkward/actions/workflows/conda-tests.yml)
[![Documentation Status](https://readthedocs.org/projects/dask-awkward/badge/?version=latest)](https://dask-awkward.readthedocs.io/en/latest/?badge=latest)
[![PyPI](https://img.shields.io/pypi/v/dask-awkward?color=blue)](https://pypi.org/project/dask-awkward)
[![Conda Forge](https://img.shields.io/conda/vn/conda-forge/dask-awkward.svg?colorB=486b87&style=flat)](https://anaconda.org/conda-forge/dask-awkward)

**This is alpha software** without any guaranteed API stability. The
dask-awkward project is affiliated with awkward-array's v1 to v2
transition. [Read more about that
here](https://github.com/scikit-hep/awkward/wiki). The first official
stable release of dask-awkward is planned for December 2022. We still
encourage willing users to experiment and report issues!

Installing
----------

If you are interested in experimenting with `dask-awkward`, we
recommend installing from the `HEAD` of the `main` branch:

```
pip install git+https://github.com/ContinuumIO/dask-awkward@main
```

Documentation
-------------

Documentation is hosted at
[https://dask-awkward.readthedocs.io/](https://dask-awkward.readthedocs.io/en/latest/index.html).
